@@ -29,11 +29,10 @@ class Prerequisites:
         if request.path == "/":
             merlin_msg = f"<a href={reverse('plugins:welcome_wizard:dashboard')}>The Nautobot Welcome Wizard can help you get started with Nautobot!</a>"
             messages.success(request, mark_safe(merlin_msg))  # nosec
-        elif request.path.startswith("/admin/"):
-            # Ignore admin pages in middleware
-            pass
         elif request.path.endswith("/add/"):
-            # model = view_func.view_class.model_form.Meta.model
+            # Check if using a Nautobot view class.
+            if not (hasattr(view_func, "view_class") and hasattr(view_func.view_class, "model_form")):
+                return
             base_fields = view_func.view_class.model_form.base_fields
             for field in base_fields:
                 if base_fields[field].required:
